@@ -3,22 +3,24 @@
 #' Computes Kullback-Leibler divergence between features and target vector.
 #'
 #' @inheritParams calc_ig
-#' @return a \code{integer} vector of length equal to the number of features 
-#' containing computed information gain values.
+#' @return A \code{numeric} vector of length 1 representing Kullback-Leibler divergence 
+#' value.
+#' @seealso \code{\link{test_features}}.
+#' Kullback-Leibler divergence is calculated using \code{\link[entropy]{KL.plugin}}.
+#' 
 #' @note Both \code{target} and \code{features} must be binary, i.e. contain only 0 
 #' and 1 values.
-#' @seealso \code{\link{test_features}}.
 #' 
-#' Kullback-Leibler divergence is calculated using \code{\link[entropy]{KL.plugin}}.
+#' The function was designed to be as fast as possible subroutine of 
+#' \code{\link{calc_criterion}} and might be cumbersome if directly called by a user.
 #' @export
-#' @references STH here
+#' @references Kullback S, Leibler RA \emph{On information and sufficiency}. Annals
+#' of Mathematical Statistics 22 (1):79-86, 1951.
 #' @examples tar <- sample(0L:1, 100, replace = TRUE)
 #' feat <- sample(0L:1, 100, replace = TRUE)
-#' prop <- c(100 - sum(tar), sum(tar))/100
-#' entr <- - sum(prop*log(prop))
-#' library(bit) #used to code vector as bit
-#' calc_kl(feat, as.bit(tar), 100, sum(tar), entr)
-calc_kl <- function(feature, target_b, len_target, pos_target, ES) {
+#' library(bit) # used to code vector as bit
+#' calc_kl(feat, as.bit(tar), 100, sum(tar))
+calc_kl <- function(feature, target_b, len_target, pos_target) {
   crosstable <- fast_crosstable(target_b, len_target, pos_target, feature)
   counts_feature <- c(crosstable[2] + crosstable[4], crosstable[1] + crosstable[3])
   
